summaryrefslogtreecommitdiffstats
path: root/src/entryeditdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryeditdialog.h')
-rw-r--r--src/entryeditdialog.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/entryeditdialog.h b/src/entryeditdialog.h
index 2d71b63..7dafffd 100644
--- a/src/entryeditdialog.h
+++ b/src/entryeditdialog.h
@@ -21,7 +21,7 @@ class KPushButton;
#include <kdialogbase.h>
-#include <qdict.h>
+#include <tqdict.h>
namespace Tellico {
namespace GUI {
@@ -33,12 +33,13 @@ namespace Tellico {
*/
class EntryEditDialog : public KDialogBase, public Observer {
Q_OBJECT
+ TQ_OBJECT
// needed for completion object support
friend class GUI::FieldWidget;
public:
- EntryEditDialog(QWidget* parent, const char* name);
+ EntryEditDialog(TQWidget* tqparent, const char* name);
/**
* Checks to see if any data needs to be saved. Returns @p true if it's ok to continue with
@@ -48,9 +49,9 @@ public:
*/
bool queryModified();
/**
- * Deletes and resets the layout of the tabs.
+ * Deletes and resets the tqlayout of the tabs.
*
- * @param coll A pointer to the collection whose fields should be used for setting up the layout
+ * @param coll A pointer to the collection whose fields should be used for setting up the tqlayout
*/
void setLayout(Data::CollPtr coll);
/**
@@ -74,7 +75,7 @@ public:
* Updates a widget when its field has been modified. The category may have changed, completions may have
* been added or removed, or what-have-you.
*
* @param coll A pointer to the parent collection
* @param oldField A pointer to the old field, which should have the same name as the new one
* @param newField A pointer to the new field
*/
@@ -135,7 +136,7 @@ private:
Data::CollPtr m_currColl;
Data::EntryVec m_currEntries;
GUI::TabControl* m_tabs;
- QDict<GUI::FieldWidget> m_widgetDict;
+ TQDict<GUI::FieldWidget> m_widgetDict;
ButtonCode m_saveBtn, m_newBtn, m_nextBtn, m_prevBtn;
@@ -74,7 +75,7 @@ public:
* been added or removed, or what-have-you.
*
- * @param coll A pointer to the parent collection
+ * @param coll A pointer to the tqparent collection
* @param oldField A pointer to the old field, which should have the same name as the new one
* @param newField A pointer to the new field